# Badger Mk -- Badge Maker

[![badge:pypi-version](https://img.shields.io/pypi/v/badger-mk.svg)](https://pypi.org/project/badger-mk)
[![badge:py-versions](https://img.shields.io/pypi/pyversions/badger-mk.svg)](https://pypi.org/project/badger-mk)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white.svg)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/lcnittl/badger-mk/master.svg)](https://results.pre-commit.ci/latest/github/lcnittl/badger-mk/master)
[![Code style: black](https://img.shields.io/badge/code_style-black-000000.svg)](https://github.com/psf/black)
[![Code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

Script for exporting a series of files after replacing placeholders in template `svg`
files with data from a `csv` file.

## Usage

### Installation

Installable with `pip` or [`pipx`][pipx] (recommended).

```cmd
pipx install badger-mk
```

### CLI

TBA.

## Platform

Should work on all major platforms.

## License

GNU General Public License v3.0 or later

See [LICENSE][license] for the full text.

[license]: LICENSE
[pipx]: https://pypi.org/project/pipx/
[pypi]: https://pypi.org/
